@@ -25,6 +25,11 @@
 import subprocess
 from classes import messagebox
 
+try:
+	import mlt
+except ImportError:
+	print "*** ERROR: MLT Python bindings failed to import ***"
+
 # init the foreign language
 from language import Language_Init
 
@@ -38,30 +43,15 @@ class formats:
 		
 	def get_filters(self, format=None):
 		""" Get a list of mlt's filters, including frei0r filters """ 
-		# melt -query 
-		command = [self.melt_command, "-query", "filters"]
-		output = ''
 		
 		filters_raw=[]
 		
-		try:
-			process = subprocess.Popen(args=command,stdout=subprocess.PIPE,
-			stdin=subprocess.PIPE,stderr=subprocess.STDOUT)
-			output = str(process.stdout.read(20000))
-			
-			# wait for process to finish, and then close
-			process.stdin.close()
-			if process.wait() != 0:
-			    print "There were some errors calling melt using os.Popen()"
-		except:
-			return filters_raw
-			
-		output_lines=output.split('\n')
-		
-		for line in output_lines:
-			if " - " in line and "..." not in line and len(line.strip()) > 0:
-				filters_raw.append(line.lstrip('  - '))
+		repo = mlt.Factory.init()
+		services = mlt.Repository.filters(repo)
 		
+		for i in range(mlt.Properties.count(services)):
+			filters_raw.append(mlt.Properties.get_name(services, i))
+			
 		# sort list
 		filters_raw.sort()
 		
@@ -93,7 +83,7 @@ class formats:
 			# wait for process to finish, and then close
 			process.stdin.close()
 			if process.wait() != 0:
-			    print "There were some errors calling melt using os.Popen()"
+				print "There were some errors calling melt using os.Popen()"
 		except:
 			return vcodecs_raw
 			
@@ -126,7 +116,7 @@ class formats:
 			# wait for process to finish, and then close
 			process.stdin.close()
 			if process.wait() != 0:
-			    print "There were some errors calling melt using os.Popen()"
+				print "There were some errors calling melt using os.Popen()"
 		except:
 			return acodecs_raw
 			
@@ -159,7 +149,7 @@ class formats:
 			# wait for process to finish, and then close
 			process.stdin.close()
 			if process.wait() != 0:
-			    print "There were some errors calling melt using os.Popen()"
+				print "There were some errors calling melt using os.Popen()"
 		except:
 			pass
 			
@@ -177,4 +167,4 @@ class formats:
 			print _("No formats or codecs were found.  Please check the OpenShot preferences and configure the 'melt' command name.")
 			messagebox.show(_("Error!"), _("No formats or codecs were found.  Please check the OpenShot preferences and configure the 'melt' command name."))
 		
-		return formats_raw
\ No newline at end of file
+		return formats_raw
