@@ -56,6 +56,7 @@ class clip:
 		self.parent = parent_track	  # the parent track this clip lives on
 		self.file_object = file_object  # the file object that this clip is linked to
 		self.unique_id = str(uuid.uuid1())
+		self.rotation = 0.0
 		
 		# init key-frame dictionary
 		self.keyframes = {"start" : keyframe(0, 100.0, 100.0, 0.0, 0.0, 1.0),
@@ -82,6 +83,13 @@ class clip:
 		# return length
 		return length
 	
+	def has_audio(self):
+		""" Determine if this clip has an audio track """
+		if self.file_object.file_type in ["video", "audio"]:
+			return True
+		else:
+			return False
+	
 	def Add_Effect(self, service):
 		# Add an effect (and it's default params) to the effect list
 		# Only add an effect if it's not already on the clip
@@ -235,7 +243,7 @@ class clip:
 		
 		# calculate what the new frame number is (and the size of the gap from the previous clip)
 		new_frame = round(self.position_on_track * fps)
-		
+
 		# determine if frames overlap
 		if current_frame != 0 and current_frame == new_frame:
 			# prevent clips from overlapping (calculate offset)
@@ -284,7 +292,8 @@ class clip:
 
 		# create the clip producer node
 		producer = dom.createElement("producer")
-		producer.setAttribute("id", self.name)
+		producer.setAttribute("id", self.unique_id)
+		producer.setAttribute("novdpau", "1")
 		producer.setAttribute("in", str(in_frame_number))
 		producer.setAttribute("out", str(out_frame_number))
 		
@@ -365,90 +374,130 @@ class clip:
 		trans_out_frame_number = ending_frame
 		current_audio_frame = trans_in_frame_number
 		
-		if self.play_audio == False or self.parent.play_audio == False:
-			# MUTE
-			filter = dom.createElement("filter")
-			filter.setAttribute("mlt_service", "volume")
-			filter.setAttribute("in", str(trans_in_frame_number))
-			filter.setAttribute("out", str(trans_out_frame_number))
-			filter.setAttribute("track", str(track_index_flipped))
-			filter.setAttribute("gain", locale.str(0))
-			
-			# add volume filter to tractor
-			tractor_node.appendChild(filter)
-		else:
-
-			# any fade in?
-			if self.audio_fade_in:
-				
-				# FADE IN
+		if self.has_audio():
+			# Only add volume nodes, if the clip might have audio
+			if self.play_audio == False or self.parent.play_audio == False:
+				# MUTE
 				filter = dom.createElement("filter")
 				filter.setAttribute("mlt_service", "volume")
-				filter.setAttribute("in", str(current_audio_frame))
-				if current_audio_frame + (self.audio_fade_amount * fps) <= trans_out_frame_number:
-					# ADD FADE AMOUNT
-					current_audio_frame = current_audio_frame + round(self.audio_fade_amount * fps)
-					filter.setAttribute("out", str(current_audio_frame))
-				else:
-					# ADJUST FADE AMOUNT TO FIT SMALLER TIME
-					current_audio_frame = trans_out_frame_number
-					filter.setAttribute("out", str(current_audio_frame))
+				filter.setAttribute("in", str(trans_in_frame_number))
+				filter.setAttribute("out", str(trans_out_frame_number))
 				filter.setAttribute("track", str(track_index_flipped))
 				filter.setAttribute("gain", locale.str(0))
-				filter.setAttribute("end", locale.str(self.volume / 100))
 				
 				# add volume filter to tractor
 				tractor_node.appendChild(filter)
+			else:
+	
+				# any fade in?
+				if self.audio_fade_in:
+					
+					# FADE IN
+					filter = dom.createElement("filter")
+					filter.setAttribute("mlt_service", "volume")
+					filter.setAttribute("in", str(current_audio_frame))
+					if current_audio_frame + (self.audio_fade_amount * fps) <= trans_out_frame_number:
+						# ADD FADE AMOUNT
+						current_audio_frame = current_audio_frame + round(self.audio_fade_amount * fps)
+						filter.setAttribute("out", str(current_audio_frame))
+					else:
+						# ADJUST FADE AMOUNT TO FIT SMALLER TIME
+						current_audio_frame = trans_out_frame_number
+						filter.setAttribute("out", str(current_audio_frame))
+					filter.setAttribute("track", str(track_index_flipped))
+					filter.setAttribute("gain", locale.str(0))
+					filter.setAttribute("end", locale.str(self.volume / 100))
+					
+					# add volume filter to tractor
+					tractor_node.appendChild(filter)
+					
+					
+				# SET REGULAR VOLUME (length between the 2 fade volume nodes)
+				if self.audio_fade_out and current_audio_frame < (trans_out_frame_number - (self.audio_fade_amount * fps)):
+					# MIDDLE TO FADE_OUT
+					
+					filter = dom.createElement("filter")
+					filter.setAttribute("mlt_service", "volume")
+					filter.setAttribute("in", str(current_audio_frame))
+					current_audio_frame = trans_out_frame_number - round(self.audio_fade_amount * fps)
+					filter.setAttribute("out", str(current_audio_frame))
+					filter.setAttribute("track", str(track_index_flipped))
+					filter.setAttribute("gain", locale.str(self.volume / 100))
+					
+					# add volume filter to tractor
+					tractor_node.appendChild(filter)
+	
+					
+				elif current_audio_frame < trans_out_frame_number:
+					# MIDDLE TO END
+	
+					filter = dom.createElement("filter")
+					filter.setAttribute("mlt_service", "volume")
+					filter.setAttribute("in", str(current_audio_frame))
+					current_audio_frame = trans_out_frame_number
+					filter.setAttribute("out", str(current_audio_frame))
+					filter.setAttribute("track", str(track_index_flipped))
+					filter.setAttribute("gain", locale.str(self.volume / 100))
+					
+					# add volume filter to tractor
+					tractor_node.appendChild(filter)
+	
 				
-				
-			# SET REGULAR VOLUME (length between the 2 fade volume nodes)
-			if self.audio_fade_out and current_audio_frame < (trans_out_frame_number - (self.audio_fade_amount * fps)):
-				# MIDDLE TO FADE_OUT
-				
-				filter = dom.createElement("filter")
-				filter.setAttribute("mlt_service", "volume")
-				filter.setAttribute("in", str(current_audio_frame))
-				current_audio_frame = trans_out_frame_number - round(self.audio_fade_amount * fps)
-				filter.setAttribute("out", str(current_audio_frame))
-				filter.setAttribute("track", str(track_index_flipped))
-				filter.setAttribute("gain", locale.str(self.volume / 100))
-				
-				# add volume filter to tractor
-				tractor_node.appendChild(filter)
-
-				
-			elif current_audio_frame < trans_out_frame_number:
-				# MIDDLE TO END
-
-				filter = dom.createElement("filter")
-				filter.setAttribute("mlt_service", "volume")
-				filter.setAttribute("in", str(current_audio_frame))
-				current_audio_frame = trans_out_frame_number
-				filter.setAttribute("out", str(current_audio_frame))
-				filter.setAttribute("track", str(track_index_flipped))
-				filter.setAttribute("gain", locale.str(self.volume / 100))
-				
-				# add volume filter to tractor
-				tractor_node.appendChild(filter)
-
-			
-			# SET FADE OUT
-			if self.audio_fade_out and current_audio_frame < trans_out_frame_number:
-
-				# FADE OUT
-				filter = dom.createElement("filter")
-				filter.setAttribute("mlt_service", "volume")
-				filter.setAttribute("in", str(current_audio_frame))
-				current_audio_frame = trans_out_frame_number
-				filter.setAttribute("out", str(current_audio_frame))
-				filter.setAttribute("track", str(track_index_flipped))
-				filter.setAttribute("gain", locale.str(self.volume / 100))
-				filter.setAttribute("end", locale.str(0))
-				
-				# add volume filter to tractor
-				tractor_node.appendChild(filter)
+				# SET FADE OUT
+				if self.audio_fade_out and current_audio_frame < trans_out_frame_number:
+	
+					# FADE OUT
+					filter = dom.createElement("filter")
+					filter.setAttribute("mlt_service", "volume")
+					filter.setAttribute("in", str(current_audio_frame))
+					current_audio_frame = trans_out_frame_number
+					filter.setAttribute("out", str(current_audio_frame))
+					filter.setAttribute("track", str(track_index_flipped))
+					filter.setAttribute("gain", locale.str(self.volume / 100))
+					filter.setAttribute("end", locale.str(0))
+					
+					# add volume filter to tractor
+					tractor_node.appendChild(filter)
 
 
+		# Create an Affine filter (behind the scenes... i.e. not in the effects list of the clip). This 
+		# filter is responsible for the smooth scaling and animation of our clip.  The alpha is still 
+		# handled by the composite transition.
+		use_affine = self.parent.parent.project.form.settings.general["use_affine"]
+		
+		# Because this requires the newest version of MLT, the affine filter is 
+		# only used when enabled in the preferences (i.e. Smooth Scaling)
+		affine_effect = self.get_affine_effect()
+		
+		# set the affine rotation (if any), and clear the default animated rotation
+		affine_effect.update_parameter("transition.rotate_x", 0.0)
+		affine_effect.update_parameter("transition.fix_rotate_x", self.rotation)
+		affine_effect.update_parameter("transition.distort", 0)
+		affine_effect.update_parameter("transition.scale_x", 0)
+		affine_effect.update_parameter("transition.scale_y", 0)
+		
+		if use_affine == "Yes":
+			# allow the affine filter to resize larger than the original image
+			affine_effect.update_parameter("use_normalised", 1)
+		else:
+			# keep the original image size
+			affine_effect.update_parameter("use_normalised", 0)
+		
+		# get the geometry (i.e. the key-frame settings)
+		affine_geometry = ""
+		if use_affine == "Yes" and (self.keyframes["start"].contains_animation() or self.keyframes["end"].contains_animation()):
+			# set affine geometry param
+			affine_geometry = "%s%s" % (self.keyframes["start"].generate_string(), self.keyframes["end"].generate_string())
+			affine_effect.update_parameter("transition.geometry", affine_geometry)
+		else:
+			# set geometry to default 
+			affine_effect.remove_parameter("transition.geometry")
+
+		# Generate XML for for affine effect
+		if affine_geometry or self.rotation:
+			# only add the 'affine' filter if rotation or animation is required
+			affine_effect.GenerateXML(dom, tractor_node, current_frame, ending_frame, track_index_flipped)
+		
 
 		# Add EFFECTS (if not in preview mode)
 		if preview_mode != "trimming":
@@ -469,46 +518,48 @@ class clip:
 				self.GenerateComposites(dom, current_frame, ending_frame, preview_mode, fps=fps)
 
 			
-			##############################
-			#			 MIX
-			##############################
-			transition = dom.createElement("transition")
-			transition.setAttribute("in", str(trans_in_frame_number))
-			transition.setAttribute("out", str(trans_out_frame_number))
-			
-			property = dom.createElement("property")
-			property.setAttribute("name", "mlt_service")
-			text = dom.createTextNode("mix")
-			property.appendChild(text)
-			transition.appendChild(property)
-			
-			property = dom.createElement("property")
-			property.setAttribute("name", "a_track")
-			text = dom.createTextNode("0")
-			property.appendChild(text)
-			transition.appendChild(property)
-			
-			property = dom.createElement("property")
-			property.setAttribute("name", "b_track")
-			text = dom.createTextNode(str(track_index_flipped))
-			property.appendChild(text)
-			transition.appendChild(property)
-			
-			# These 2 properties combine the audio from 2 tracks equally
-			property = dom.createElement("property")
-			property.setAttribute("name", "combine")
-			text = dom.createTextNode("1")
-			property.appendChild(text)
-			transition.appendChild(property)
-			
-			property = dom.createElement("property")
-			property.setAttribute("name", "always_active")
-			text = dom.createTextNode("1")
-			property.appendChild(text)
-			transition.appendChild(property)
-
-			# add composite transition to tractor
-			tractor_node.appendChild(transition)
+			if self.has_audio():
+				# Only add the audio MIX transition if the clip might have audio
+				##############################
+				#			 MIX
+				##############################
+				transition = dom.createElement("transition")
+				transition.setAttribute("in", str(trans_in_frame_number))
+				transition.setAttribute("out", str(trans_out_frame_number))
+				
+				property = dom.createElement("property")
+				property.setAttribute("name", "mlt_service")
+				text = dom.createTextNode("mix")
+				property.appendChild(text)
+				transition.appendChild(property)
+				
+				property = dom.createElement("property")
+				property.setAttribute("name", "a_track")
+				text = dom.createTextNode("0")
+				property.appendChild(text)
+				transition.appendChild(property)
+				
+				property = dom.createElement("property")
+				property.setAttribute("name", "b_track")
+				text = dom.createTextNode(str(track_index_flipped))
+				property.appendChild(text)
+				transition.appendChild(property)
+				
+				# These 2 properties combine the audio from 2 tracks equally
+				property = dom.createElement("property")
+				property.setAttribute("name", "combine")
+				text = dom.createTextNode("1")
+				property.appendChild(text)
+				transition.appendChild(property)
+				
+				property = dom.createElement("property")
+				property.setAttribute("name", "always_active")
+				text = dom.createTextNode("1")
+				property.appendChild(text)
+				transition.appendChild(property)
+	
+				# add composite transition to tractor
+				tractor_node.appendChild(transition)
 			
 		# return # of frames for this clip
 		return ending_frame
@@ -715,6 +766,19 @@ class clip:
 				# MASK
 				a1 = t.mask_value / 100
 				a2 = t.mask_value / 100
+				
+		use_affine = self.parent.parent.project.form.settings.general["use_affine"]
+		if use_affine == "Yes":
+			# Because this requires the newest version of MLT, the affine filter is 
+			# only used when enabled in the preferences (i.e. Smooth Scaling).  If affine is 
+			# enabled, we do not need the composite transition to scale or move the image...
+			# so we set those settings back to their defaults.
+			
+			# override all x,y,h,w variables, and leave this composite 100%x100%.  The scaling
+			# is now being done by a built-in affine filter.  The Alpha, transitions, and masks are still 
+			# handled by this geometry though.
+			x1,y1,x2,y2 = 0.0, 0.0, 0.0, 0.0
+			w1,h1,w2,h2 = 100.0, 100.0, 100.0, 100.0
 		
 		geometry_start = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (0, locale.str(x1), locale.str(y1), locale.str(w1), locale.str(h1), locale.str(a1 * 100.0))
 		geometry_end = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (-1, locale.str(x2), locale.str(y2), locale.str(w2), locale.str(h2), locale.str(a2 * 100.0))
@@ -760,22 +824,42 @@ class clip:
 		
 		# Is this a transition?
 		if t:
-			property = dom.createElement("property")
-			property.setAttribute("name", "luma")
-			text = dom.createTextNode(t.resource)
-			property.appendChild(text)
-			transition.appendChild(property)
+			if t.resource:
+				property = dom.createElement("property")
+				property.setAttribute("name", "luma")
+				text = dom.createTextNode(t.resource)
+				property.appendChild(text)
+				transition.appendChild(property)
 			
-			property = dom.createElement("property")
-			property.setAttribute("name", "softness")
-			text = dom.createTextNode(locale.str(t.softness))
-			property.appendChild(text)
-			transition.appendChild(property)
+			if t.softness:
+				property = dom.createElement("property")
+				property.setAttribute("name", "softness")
+				text = dom.createTextNode(locale.str(t.softness))
+				property.appendChild(text)
+				transition.appendChild(property)
 		
 		# add composite transition to tractor
 		tractor_node.appendChild(transition)
 				
 				
+	def get_affine_effect(self):
+		
+		# Get list of effects
+		my_effects = self.parent.parent.project.form.effect_list
+		
+		# Look up default params
+		for my_effect in my_effects:
+			# find matching effect
+			if my_effect.service == "affine":
+				# get list of default params
+				default_params = my_effect.get_default_params()
+				
+				# create new effect object
+				return effect.effect("affine", default_params)
+		
+		# else, return none
+		return None
+				
 
 	def get_keyframe_values(self, prop_name, current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end):
 		
@@ -1249,7 +1333,7 @@ class clip:
 				if self.effects:
 					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/effect.png" % (self.parent.parent.project.form.openshot_path, theme))
 				
-				# Add Visible Image to Group
+				# Add Effect Image to Group
 					image5 = goocanvas.Image (parent = GroupClip,
 										  pixbuf = imgTrack_Visible.get_pixbuf(),
 										  x = x + theme_settings["clip"]["effect"]["x"],
@@ -1258,6 +1342,7 @@ class clip:
 					# Track the state of the hover over image
 					image5.set_data ("id", "effect")
 					image5.connect ("button_press_event", self.on_effect_click)
+					image5.connect ("button_release_event", self.on_effect_release)
 				
 			else:
 				if self.effects:
@@ -1497,7 +1582,18 @@ class clip:
 				parent_track.clips.append(self)
 				self.parent = parent_track
 
-	
+
+	def show_properties(self, clipitem, initial_tab):
+		""" Launch the clip properites, and switch to the correct tab """
+		# reset the cursor icon
+		self.parent.parent.project.form.MyCanvas.window.set_cursor(gtk.gdk.Cursor(150))
+		
+		# Open clip properties
+		from windows import ClipProperties
+		self.parent.parent.project.form.frmClipProperties = ClipProperties.frmClipProperties(form=self.parent.parent.project.form, project=self.parent.parent.project, current_clip=self, current_clip_item=clipitem, initial_tab=initial_tab)
+		
+		# reset the cursor icon
+		self.parent.parent.project.form.MyCanvas.window.set_cursor(None)
 	
 	def on_button_press_x (self, item, target, event):
 		""" This method initializes some variables needed for dragging and dropping a clip """
@@ -1560,6 +1656,11 @@ class clip:
 					self.stored_y = item.get_bounds().y1
 					canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
 
+				if (event.state == gtk.gdk.CONTROL_MASK) or (event.state == gtk.gdk.CONTROL_MASK | gtk.gdk.MOD2_MASK):
+					self.request_show_properties = True
+				else:
+					self.request_show_properties = False
+					
 			
 			# RAZOR MODE
 			elif isRazor:
@@ -1610,7 +1711,7 @@ class clip:
 		self.parent.parent.play_head.raise_(None)
 		self.parent.parent.play_head_line.raise_(None)
  
-		return True
+		return False
 	
 	
 	def set_preview_mode(self):
@@ -1709,6 +1810,11 @@ class clip:
 		# re-order clip objects on track (since they might be out of order now)
 		self.parent.reorder_clips()
 		
+		# raise play-head above clips
+		if self.parent.parent.project.sequences[0].play_head:
+			self.parent.parent.project.sequences[0].play_head.raise_(None)
+			self.parent.parent.project.sequences[0].play_head_line.raise_(None)
+		
 		# mark project as modified
 		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Sliced clip"))
 					
@@ -1827,7 +1933,7 @@ class clip:
 			self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
 			drop_track.reorder_clips()  
 	
-			# deterime the direction of the drag
+			# determine the direction of the drag
 			if isSnap:
 				distance_from_clip = self.get_snap_difference(self, item)
 			else:
@@ -1853,6 +1959,9 @@ class clip:
 				# Mark clip as modified
 				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
 
+
+			if self.request_show_properties:
+				self.show_properties(item, 0)
 			
 		elif isResize:
 			
@@ -2002,12 +2111,24 @@ class clip:
 		
 	
 	def on_effect_click (self, item, target, event):
-		pass
-		#form1 = self.parent.parent.project.form
-		#from windows import ClipProperties
-		#form1.frmClipProperties = ClipProperties.frmClipProperties(form=form1, project=self.parent.parent.project, current_clip=self, current_clip_item=item)
-		#return True
+		
+		# CHECK FOR DOUBLE-CLICK
+		if event.type == gtk.gdk._2BUTTON_PRESS:
+			# Get the effect icon parent (i.e. the clip CanvasGroup)
+			clip_item = item.get_parent()
+			
+			# Show the clip properties
+			self.show_properties(clip_item, 6)
+			
+		return True
 	
+	def on_effect_release(self, item, target, event):
+		# get reference to the canvas, and stop dragging the item
+		canvas = item.get_canvas()
+		canvas.pointer_ungrab (item, event.time)
+		
+		return True
+
 	def on_clip_buttons_release(self, item, target, event):
 		return True
 		
@@ -2020,9 +2141,10 @@ class clip:
 		# Check for missing DEBUG attribute (which means it's an old project format)
 		if 'effects' not in state:
 			state['effects'] = []
-			
 		if 'speed' not in state:
 			state['speed'] = 1.0
+		if 'rotation' not in state:
+			state['rotation'] = 0.0
 
 		# update the state object with new schema changes
 		self.__dict__.update(state)
