@@ -16,8 +16,8 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-VERSION             = "1.2.2"
-DATE                = "20100919170000"
+VERSION             = "1.3.0"
+DATE                = "20110213000000"
 NAME                = 'openshot'
 GPL_VERSION         = '3'
 SUPPORTED_LANGUAGES = ['English', 'Dutch', 'French', 'German', 'Italian', 'Portuguese', 'Spanish', 'Swedish']
@@ -31,7 +31,6 @@ TJ   = {'name': u'TJ', 'email': 'ubuntu@tjworld.net'}
 MA   = {'name': u'Mael Lavault', 'email': 'moimael@neuf.fr'}
 IM   = {'name': u'itomailg', 'email': 'itomailg@gmail.com'}
 
-
 #credits
 CREDITS = {
     'code'          : [JT, AF, TJ, OG, MA, IM],
@@ -49,12 +48,12 @@ SETUP   = {
     'url'               : 'http://www.openshotvideo.com/',
     'license'           : 'GNU GPL v.' + GPL_VERSION,
 	'description'	   : 'Create and edit videos and movies',
-	'long_description'  : "Create and edit videos and movies\n OpenShot Video Editor is a free, open-source, non-linear video editor.  It\n can create and edit videos and movies using many popular video, audio, and\n image formats.  Create videos for YouTube, Flickr, Vimeo, Metacafe, iPod,\n Xbox, and many more common formats!\n .\n Features include:\n  * Multiple tracks (layers)\n  * Compositing, image overlays, and watermarks\n  * Support for image sequences (rotoscoping)\n  * Key-frame animation\n  * Video and audio effects (chroma-key)\n  * Transitions (lumas and masks)",
+	'long_description'  : "Create and edit videos and movies\n OpenShot Video Editor is a free, open-source, non-linear video editor.  It\n can create and edit videos and movies using many popular video, audio, and\n image formats.  Create videos for YouTube, Flickr, Vimeo, Metacafe, iPod,\n Xbox, and many more common formats!\n .\n Features include:\n  * Multiple tracks (layers)\n  * Compositing, image overlays, and watermarks\n  * Support for image sequences (rotoscoping)\n  * Key-frame animation\n  * Video and audio effects (chroma-key)\n  * Transitions (lumas and masks)\n  * 3D animation (titles and simulations)\n  * Upload videos (YouTube and Vimeo supported)",
 		 
 
 # see http://pypi.python.org/pypi?%3Aaction=list_classifiers
     'classifiers'       : [          
-                           'Development Status :: 4 - Beta',
+                           'Development Status :: 5 - Production/Stable',
                            'Environment :: X11 Applications',
                            'Environment :: X11 Applications :: GTK',
                            'Intended Audience :: End Users/Desktop',
