@@ -41,9 +41,9 @@ class sequence:
 		self.name = seq_name
 		self.length = 600.0		   # length in seconds of sequence.  This controls how wide to render the tracks.
 		self.project = project	  # reference to current project
-		self.scale = 15.0		   # this represents how many seconds per tick mark
+		self.scale = 8.0		   # this represents how many seconds per tick mark
 		self.tick_pixels = 100	  # number of pixels between each tick mark
-		self.play_head_position = 0 # position of the play head in seconds
+		self.play_head_position = 0.0 # position of the play head in seconds
 		
 		# init the tracks on the sequence
 		self.tracks = []
@@ -57,6 +57,7 @@ class sequence:
 		self.play_head = None
 		self.ruler_time = None
 		self.play_head_line = None
+		self.enable_animated_playhead = True
 		
 		
 	def AddMarker(self, marker_name, position_on_track):
@@ -261,9 +262,18 @@ class sequence:
 		# determine position of playhead
 		time = timeline.timeline().get_friendly_time(self.play_head_position * 1000) 
 		
+		# Get theme settings
+		theme = self.project.theme
+ 		theme_settings = self.project.theme_settings.settings
+
 		# set the top coordinate of this track to the bottom coordinate of the last track
-		x = 10	  
-		y_top = 12
+		x = theme_settings["timeline"]["ruler"]["x"]	  
+		y_top = theme_settings["timeline"]["ruler"]["y"]
+		
+		# determine the height of the timeline
+		imgTrack_Track = gtk.image_new_from_file("%s/openshot/themes/%s/Track_Middle.png" % (self.project.form.openshot_path, theme))
+		imgTrack_Track_Height = imgTrack_Track.get_pixbuf().get_height()
+		timeline_heigth = len(self.tracks) * imgTrack_Track_Height + (len(self.tracks) * theme_settings["track"]["padding"]) + 10
 		
 		# get a reference to the 2 main canvas objects & theme
 		theme = self.project.theme
@@ -272,9 +282,6 @@ class sequence:
 		canvas_left = self.project.form.TimelineCanvas_Left
 		canvas_right = self.project.form.TimelineCanvas_Right
 		
- 		# Get theme settings
- 		theme_settings = self.project.theme_settings.settings
-		
 		# Add an item to the goocanvas
 		root_left = canvas_left.get_root_item ()
 		root_right = canvas_right.get_root_item ()
@@ -294,8 +301,14 @@ class sequence:
 		Size_Of_Middle = int(pixels_per_second * self.length)
 		
 		# resize the canvas height and width
-		canvas_timeline.set_bounds (0, 0, Size_Of_Middle + 185, 5000)
-		self.project.form.hscrollbar2.set_range(0, Size_Of_Middle + 200)
+		new_size_of_middle = Size_Of_Middle + 200
+		if new_size_of_middle > 32000:
+			# do not let the size of the canvas exceed 32,000... or cairo will throw an error
+			new_size_of_middle = 32000
+			
+		canvas_timeline.set_bounds (0, 0, new_size_of_middle, timeline_heigth)
+		self.project.form.hscrollbar2.set_range(0, new_size_of_middle)
+		self.project.form.vscrollbar2.set_range(0, timeline_heigth)
 		self.project.form.on_hscrollbar2_value_changed(self.project.form.hscrollbar2)
 		
 		# Get the height of the RULER
@@ -303,14 +316,14 @@ class sequence:
 		left_canvas_width = theme_settings["track"]["track_name_text"]["w"]
 		
 		# Resize the LEFT RULER
-		canvas_timeline_left.set_bounds (0, 0, left_canvas_width, 5000)
+		canvas_timeline_left.set_bounds (0, 0, left_canvas_width, timeline_heigth)
 		canvas_left.set_bounds (0, 0, left_canvas_width, ruler_height)
 		canvas_left.set_size_request (0, ruler_height)
 		self.project.form.timelineWindowLeft.set_size_request (left_canvas_width, ruler_height)
 		self.project.form.scrolledwindow_Left.set_size_request (left_canvas_width, 0)
 		
 		# Resize the RIGHT RULER
-		canvas_right.set_bounds (0, 0, Size_Of_Middle + 200, ruler_height)
+		canvas_right.set_bounds (0, 0, new_size_of_middle + 16, ruler_height)
 		canvas_right.set_size_request (0, ruler_height)
 		self.project.form.timelinewindowRight.set_size_request (0, ruler_height)
 		
@@ -368,6 +381,9 @@ class sequence:
 		# loop through each tick mark
 		number_of_ticks = int(self.length / self.scale)
 		ruler_pixels = ((float(self.length) / float(self.scale)) * self.tick_pixels)
+		if ruler_pixels > 32000:
+			ruler_pixels = 32000
+			
 		tick = 0
 		end_of_timeline = False
 		
@@ -434,12 +450,16 @@ class sequence:
 		# Connect signals to ruler to allow drag and drop
 		GroupTrack.connect ("button_press_event", self.on_ruler_press)
 		GroupTrack.connect ("motion_notify_event", self.on_ruler_motion)
+		GroupTrack.connect ("button_release_event", self.on_ruler_release)
 		
 
 				
 
 	def on_ruler_press(self, item, target, event):
 		
+		# enable animated playhead
+		self.enable_animated_playhead = True
+		
 		if event.button == 1:
 			new_x = event.x
 			
@@ -447,40 +467,41 @@ class sequence:
 			pixels_per_second = self.get_pixels_per_second()
 
 			# calculate playhead position
-			self.play_head_position = new_x / pixels_per_second
-			
-			if self.play_head_position < 0:
-				self.play_head_position = 0
-			
-			# move playhead
-			self.project.form.MyVideo.move_play_head(self.play_head_position)
+			play_head_position = new_x / pixels_per_second
 			
+			if play_head_position < 0:
+				play_head_position = 0
+
 			# update video frame
-			self.update_video()
+			self.update_video(play_head_position)
 
 			
 
 	def on_ruler_motion(self, item, target, event):
 		#print "on_ruler_motion"
-
+		
 		if (event.state & gtk.gdk.BUTTON1_MASK):
 			new_x = event.x
 			
+			# disable animated playhead
+			self.enable_animated_playhead = False
+			
 			# get the pixels per second from the parent sequence
 			pixels_per_second = self.get_pixels_per_second()
 
 			# calculate playhead position
-			self.play_head_position = new_x / pixels_per_second
+			play_head_position = new_x / pixels_per_second
 			
-			if self.play_head_position < 0:
-				self.play_head_position = 0
-			
-			# move playhead
-			self.project.form.MyVideo.move_play_head(self.play_head_position)
+			if play_head_position < 0:
+				play_head_position = 0
 			
 			# update video frame
-			self.update_video()
+			self.update_video(play_head_position)
 	
+	def on_ruler_release(self, item, target, event):
+
+		# enable animated playhead
+		self.enable_animated_playhead = True
 	
 	#----------------------------------------------------------------------
 	def RenderMarkers(self):
@@ -511,7 +532,7 @@ class sequence:
 	#----------------------------------------------------------------------
 	def RenderPlayHead(self):
 		"""This adds the playhead to the canvas, and the play head position line"""
-		
+
  		# Get theme settings
  		theme_settings = self.project.theme_settings.settings
 		
@@ -599,6 +620,9 @@ class sequence:
 			new_x = event.x
 			new_y = event.y
 			
+			# disable animated playhead
+			self.enable_animated_playhead = False
+			
 			# get the pixels per second from the parent sequence
 			pixels_per_second = self.get_pixels_per_second()
 			
@@ -617,15 +641,15 @@ class sequence:
 			self.play_head_line.translate(total_x_diff, 0)
 
 			# update playhead position
-			self.play_head_position = (item.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
+			play_head_position = (item.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
 			
 			# update video frame
-			self.update_video()
+			self.update_video(play_head_position)
 
 		return True
 	
 	
-	def update_video(self):
+	def update_video(self, play_head_position):
 		
 		# return to "preview" mode (if in override mode)
 		if self.project.form.MyVideo.mode == "override":
@@ -635,7 +659,7 @@ class sequence:
 		self.project.RefreshXML()
 		
 		# determine new frame number
-		frame = self.project.fps() * self.play_head_position
+		frame = self.project.fps() * play_head_position
 		
 		# seek to the new frame
 		self.project.form.MyVideo.seek(int(frame))
@@ -644,9 +668,12 @@ class sequence:
 	def move_play_head (self, new_time):
 		"""this method allows the play head to be moved to a specific spot on the timeline.  It accepts
 		a parameter for the # of seconds to move the playhead to."""
-		
+
 		# move play_head to the top layer
 		if self.play_head and new_time != self.play_head_position:
+			
+			# keep track of the current play-head position
+			self.play_head_position = float(new_time)
 
 			self.play_head.raise_(None)
 			self.play_head_line.raise_(None)
@@ -661,7 +688,12 @@ class sequence:
 			# don't allow the clip to slide past the beginning of the canvas
 			total_x_diff = (new_time * pixels_per_second) - (self.play_head.get_bounds().x2 + min_x)
 	
-			# move clip				
+			# animate clip (if needed)
+			if self.enable_animated_playhead == True:
+				self.play_head.animate(total_x_diff, 0, 1.0, 0.0, False, 100, 4, goocanvas.ANIMATE_FREEZE)
+				self.play_head_line.animate(total_x_diff, 0, 1.0, 0.0, False, 100, 4, goocanvas.ANIMATE_FREEZE)
+	
+			# move clip
 			self.play_head.translate (total_x_diff, 0)
 			self.play_head_line.translate (total_x_diff, 0)
 			
@@ -673,15 +705,14 @@ class sequence:
 			time = timeline.timeline().get_friendly_time(milliseconds)
 			frame = round((time[5] / 1000.0) * self.project.fps())
 			self.ruler_time.set_property("text", theme_settings["timeline"]["playhead_text"]["font"] % (time[2], time[3], time[4], frame))
-						
-			# update playhead position
-			self.play_head_position = (self.play_head.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
-
 	
 	
 	def on_button_press_x (self, item, target, event):
 		""" This method initializes some variables needed for dragging and dropping a clip """
 
+		# enable animated playhead
+		self.enable_animated_playhead = True
+
 		# raise the group up to the top level
 		item.raise_(None)
 
@@ -716,6 +747,8 @@ class sequence:
 		canvas = item.get_canvas ()
 		canvas.pointer_ungrab (item, event.time)
 	
+		# enable animated playhead
+		self.enable_animated_playhead = True
 				
 		
 	def split_images(self, pixbuf, height, max_length):
@@ -859,6 +892,17 @@ class sequence:
 		# return false if no valid track found
 		return None
 		
-		
+	#----------------------------------------------------------------------
+	def __setstate__(self, state):
+		""" This method is called when an OpenShot project file is un-pickled (i.e. opened).  It can
+		    be used to update the structure of old clip classes, to make old project files compatable with
+		    newer versions of OpenShot. """
+	
+		# Check for missing DEBUG attribute (which means it's an old project format)
+		if 'enable_animated_playhead' not in state:
+			state['enable_animated_playhead'] = False
+
+		# update the state object with new schema changes
+		self.__dict__.update(state)
 		
 		
