@@ -115,9 +115,20 @@ class track:
 	def RenderTrack(self):
 		"""This adds a track to the canvas with 3 images: a left, middle, and right"""
 
+		# get a reference to the language translate method
+		_ = self.parent.project.translate
+
 		# get the pixels per second from the parent sequence
 		pixels_per_second = self.parent.get_pixels_per_second()
 		
+		# get a reference to the 2 main canvas objects & theme
+		theme = self.parent.project.theme
+		canvas_left = self.parent.project.form.MyCanvas_Left
+		canvas_right = self.parent.project.form.MyCanvas
+		
+ 		# Get theme settings
+ 		theme_settings = self.parent.project.theme_settings.settings
+		
 		# get the previous track from the parent sequence (if any)
 		previous_track_index = self.parent.tracks.index(self) - 1
 		previous_track = None
@@ -130,13 +141,8 @@ class track:
 			previous_y_bottom = previous_track.y_bottom
 		
 		# set the top coordinate of this track to the bottom coordinate of the last track
-		self.y_top = previous_y_bottom + 6
-		
-		# get a reference to the 2 main canvas objects & theme
-		theme = self.parent.project.theme
-		canvas_left = self.parent.project.form.MyCanvas_Left
-		canvas_right = self.parent.project.form.MyCanvas
-		
+		self.y_top = previous_y_bottom + theme_settings["track"]["padding"]
+
 		# Add an item to the goocanvas
 		root_left = canvas_left.get_root_item ()
 		root_right = canvas_right.get_root_item ()
@@ -194,60 +200,65 @@ class track:
 		image3 = goocanvas.Image (parent = GroupTrack,
 								  pixbuf = imgTrack_Right.get_pixbuf(),
 								  x = Size_Of_Middle - 1,
-								  y = self.y_top)	
+								  y = self.y_top)
 		
 		# Add Text to the Track
 		text1 = goocanvas.Text (parent = GroupTrack_Left,
-								text = "%s" % self.name,
-								font = "Sans 9",
+								text = theme_settings["track"]["track_name_text"]["font"] % self.name,
 								antialias = False,
-								x = self.x + 8,
-								y = self.y_top + 7)
+								use_markup = True,
+								x = self.x + theme_settings["track"]["track_name_text"]["x"],
+								y = self.y_top + theme_settings["track"]["track_name_text"]["y"])
 		
 		# Load buttons
 		if self.play_video:
 			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/visible.png" % (self.parent.project.form.openshot_path, theme))
+			imgTrack_Visible.set_tooltip_text(_("Video Visible"))
 		else:
 			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible.png" % (self.parent.project.form.openshot_path, theme))
+			imgTrack_Visible.set_tooltip_text(_("Video not Visible"))
 		if self.play_audio:
 			imgTrack_Audio = gtk.image_new_from_file("%s/openshot/themes/%s/speaker.png" % (self.parent.project.form.openshot_path, theme))
+			imgTrack_Audio.set_tooltip_text(_("Sound Activated"))
 		else:
 			imgTrack_Audio = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute.png" % (self.parent.project.form.openshot_path, theme))
+			imgTrack_Audio.set_tooltip_text(_("Sound Deactivated"))
 		
 		# Add Visible Image to Group
-		image4 = goocanvas.Image (parent = GroupTrack_Left,
-								  pixbuf = imgTrack_Visible.get_pixbuf(),
-								  x = self.x + 7,
-								  y = self.y_top + 27)  
+		image4 = goocanvas.Widget (parent = GroupTrack_Left,
+								  widget = imgTrack_Visible,
+								  x = self.x + theme_settings["track"]["visible"]["x"],
+								  y = self.y_top + theme_settings["track"]["visible"]["y"])  
 		
 		# Track the state of the hover over image
 		image4.connect ("button_press_event", self.on_visible_click)
 		
-		# Add Visible Image to Group
-		image5 = goocanvas.Image (parent = GroupTrack_Left,
-								  pixbuf = imgTrack_Audio.get_pixbuf(),
-								  x = self.x + 28,
-								  y = self.y_top + 27)  
+		# Add Audio Image to Group
+		image5 = goocanvas.Widget (parent = GroupTrack_Left,
+								  widget = imgTrack_Audio,
+								  x = self.x + theme_settings["track"]["speaker"]["x"],
+								  y = self.y_top + theme_settings["track"]["speaker"]["y"])  
 		
 		# Track the state of the hover over image
 		image5.connect ("button_press_event", self.on_audio_click)
 		
 		# Increment the Y cooridinate (by the height of the left image)
 		self.y_bottom = self.y_top + imgTrack_Left_Height
-		
 
-		
 
 	def on_visible_click (self, item, target, event):
 
+		# get a reference to the language translate method
+		_ = self.parent.project.translate
+
 		# get the parent left group
 		parent_group = item.get_parent()
-		
 
 		if self.play_video == True:
 			# Load Hover Over
 			imgTrack_Left_Hover = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible.png" % (self.parent.project.form.openshot_path, self.parent.project.theme))
-			item.set_properties(pixbuf = imgTrack_Left_Hover.get_pixbuf())
+			imgTrack_Left_Hover.set_tooltip_text(_("Video not Visible"))
+			item.set_properties(widget = imgTrack_Left_Hover)
 			
 			# update play video variable
 			self.play_video = False
@@ -255,7 +266,8 @@ class track:
 		else: 
 			# Load normal image
 			imgTrack_Left_Hover = gtk.image_new_from_file("%s/openshot/themes/%s/visible.png" % (self.parent.project.form.openshot_path, self.parent.project.theme))
-			item.set_properties(pixbuf = imgTrack_Left_Hover.get_pixbuf())
+			imgTrack_Left_Hover.set_tooltip_text(_("Video Visible"))
+			item.set_properties(widget = imgTrack_Left_Hover)
 
 			# update play video variable
 			self.play_video = True
@@ -269,14 +281,17 @@ class track:
 	
 	def on_audio_click (self, item, target, event):
 
+		# get a reference to the language translate method
+		_ = self.parent.project.translate
+
 		# get the parent left group
 		parent_group = item.get_parent()
-		
 
 		if self.play_audio == True:
 			# Load Hover Over
 			imgTrack_Left_Hover = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute.png" % (self.parent.project.form.openshot_path, self.parent.project.theme))
-			item.set_properties(pixbuf = imgTrack_Left_Hover.get_pixbuf())
+			imgTrack_Left_Hover.set_tooltip_text(_("Sound Deactivated"))
+			item.set_properties(widget = imgTrack_Left_Hover)
 			
 			# update play audio variable
 			self.play_audio = False
@@ -284,7 +299,8 @@ class track:
 		else: 
 			# Load normal image
 			imgTrack_Left_Hover = gtk.image_new_from_file("%s/openshot/themes/%s/speaker.png" % (self.parent.project.form.openshot_path, self.parent.project.theme))
-			item.set_properties(pixbuf = imgTrack_Left_Hover.get_pixbuf())
+			imgTrack_Left_Hover.set_tooltip_text(_("Sound Activated"))
+			item.set_properties(widget = imgTrack_Left_Hover)
 			
 			# update play audio variable
 			self.play_audio = True
