@@ -52,10 +52,16 @@ class frmAbout(SimpleGtkBuilderApp):
 			email = person['email']
 			authors.append("%s <%s>" % (name, email))
 		self.aboutdialog1.set_documenters(authors)
-		
-		# init translators
-		self.aboutdialog1.set_translator_credits("Translation credits are located on LaunchPad:\nhttps://translations.launchpad.net/openshot")
 
+		# string used to store the authors of translations:
+		self.translation_authors = _("translator-credits")
+		if self.translation_authors == "translator-credits":
+			self.translation_authors = "Translation credits are located on LaunchPad:\nhttp://translations.launchpad.net/openshot"
+		else:
+			# replace all https links with http, so the AboutDialog will make them clickable.
+			self.translation_authors = self.translation_authors.replace("https://", "http://")
+		
+		self.aboutdialog1.set_translator_credits(self.translation_authors)
 
 
 	def new(self):
