@@ -35,12 +35,24 @@ class frmAddEffect(SimpleGtkBuilderApp):
 		self.form = form
 		self.project = project
 		self.parent = parent
-		self.frmAddEffect.show_all()
+		EFFECTS_DIR = self.project.EFFECTS_DIR
+
+		# Init Dropdown and model
+		# create a ListStore
+		self.store = gtk.ListStore(gtk.gdk.Pixbuf, str)
+		self.sort_model = gtk.TreeModelSort(self.store)
+		
+		# Sort Effects ListStore
+		self.sort_model.set_sort_column_id(1, gtk.SORT_ASCENDING)
+
+		# Set the treeview's data model
+		self.cboEffects.set_model(self.sort_model)
 		
 		# Init List of Effects
 		effect_list = self.form.effect_list
 		
 		# Add effects to dropdown
+		sorted_list = []
 		for my_effect in effect_list:
 			
 			# is frei0r effect library installed?
@@ -49,9 +61,19 @@ class frmAddEffect(SimpleGtkBuilderApp):
 				# skip to next item in loop
 				continue
 			
-			# add item
-			self.cboEffects.append_text(my_effect.title)
-		
+			# get image for filter
+			file_path = os.path.join(EFFECTS_DIR, "icons", "small", my_effect.icon)
+			
+			# get the pixbuf
+			pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
+
+			# add effect to tree
+			item = self.store.append(None)
+			self.store.set_value(item, 0, pbThumb)
+			self.store.set_value(item, 1, _(my_effect.title))
+
+		# show all controls
+		self.frmAddEffect.show_all()
 		
 		
 	def on_btnCancel_clicked(self, widget, *args):
@@ -76,7 +98,14 @@ class frmAddEffect(SimpleGtkBuilderApp):
 		print "on_btnOk_clicked"
 
 		# get Service name
-		effect_title = self.cboEffects.get_active_text()
+		iter = self.cboEffects.get_active_iter()
+		
+		if not iter:
+			# don't do anything if no effect is selected
+			return
+		
+		# Get effect name
+		effect_title = self.cboEffects.get_model().get_value(iter, 1)
 		
 		# Add the effect
 		if effect_title:
