@@ -19,9 +19,10 @@
 import os, time, uuid, shutil
 import gobject, threading, subprocess, re
 import gtk
+import subprocess
 from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from windows import preferences, TreeBlender
-from classes import project, messagebox
+from classes import project, messagebox, files
 
 # init the foreign language
 from language import Language_Init
@@ -68,9 +69,47 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		self.sliderPreview.set_sensitive(False)
 		self.btnRefresh.set_sensitive(False)
 		
+		# Get a list of all TTF files (i.e. font files) on the users (as fast as possible)
+		# computer, so that we can pass these into Blender to set the font.
+		self.available_fonts = self.get_font_files()
+		
 		
 	def get_font_files(self):
-		""" Get a list of font files on the computer. """
+		""" Get a list of font files on the computer as FAST as possible. """
+
+		# fc-list : file family style
+		command = ["fc-list", ":", "file", "family", "style"]
+		regexp = re.compile("([^:]*): ?([^:,]*)(,[^:]*)?(:style=([^,]*)(,.*)?)?")
+
+		ttf_raw={}
+		
+		try:
+			process = subprocess.Popen(args=command,stdout=subprocess.PIPE)
+			output = str(process.stdout.read())
+			
+			# wait for process to finish, and then close
+			if process.wait() != 0:
+				print "There were some errors calling 'fc-list' using subprocess.Popen()"
+		except:
+			return ttf_raw
+			
+		output_lines=output.split('\n')
+		
+		for line in output_lines:
+			try:
+				filename, family, style = regexp.match(line).group(1, 2, 5)
+				
+				# get friendly font name
+				friendly_name = "%s %s" % (family, style) if style else family
+				
+				# add font to dictionary
+				ttf_raw[friendly_name] = filename
+				
+			except:
+				pass
+		
+		# sort list
+		return ttf_raw
 
 
 	def on_btnRefresh_clicked(self, widget, *args):
@@ -197,12 +236,30 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 				elif param.type == "dropdown":
 					# add value to dictionary
 					self.params[param.name] = param.default
-					
+
+					# override font dropdown
+					if param.name == "fontname":
+						param.values = {"Bfont":"Bfont"}
+						for k,v in self.available_fonts.items():
+							param.values[k] = v
+							
+					# override files dropdown
+					if "project_files" in param.name:
+						param.values = {}
+						for item in self.project.project_folder.items:
+							if isinstance(item, files.OpenShotFile):
+								if item.file_type in ("image", "video"):
+									(dirName, fileName) = os.path.split(item.name)
+									(fileBaseName, fileExtension)=os.path.splitext(fileName)
+									
+									if fileExtension.lower() not in (".svg"):
+										param.values[fileName] = "|".join((item.name, str(item.height), str(item.width), item.file_type, str(item.fps)))
+
 					cboBox = gtk.combo_box_new_text()
 					
 					# add values
 					box_index = 0
-					for k,v in param.values.items():
+					for k,v in sorted(param.values.items()):
 						# add dropdown item
 						cboBox.append_text(_(k))
 						
@@ -344,7 +401,10 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		project_params["resolution_x"] = int(self.project.mlt_profile.width())
 		project_params["resolution_y"] = int(self.project.mlt_profile.height())
 		
-		project_params["resolution_percentage"] = 100
+		if is_preview:
+			project_params["resolution_percentage"] = 50
+		else:
+			project_params["resolution_percentage"] = 100
 		project_params["quality"] = 100
 		project_params["file_format"] = "PNG"
 		if is_preview:
@@ -529,7 +589,7 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 			version_message = _("\n\nError Output:\n%s") % command_output
 		
 		# show error message
-		messagebox.show(_("Blender Error"), _("Blender, the free open source 3D content creation suite is required for this action (http://www.blender.org).\n\nPlease check the preferences in OpenShot and be sure the Blender executable is correct.  This setting should be the path of the 'blender' executable on your computer.  Also, please be sure that it is pointing to Blender version 2.5 or greater.\n\nBlender Path:\n%s%s") % (self.form.settings.general["blender_command"], version_message))
+		messagebox.show(_("Blender Error"), _("Blender, the free open source 3D content creation suite is required for this action (http://www.blender.org).\n\nPlease check the preferences in OpenShot and be sure the Blender executable is correct.  This setting should be the path of the 'blender' executable on your computer.  Also, please be sure that it is pointing to Blender version 2.56 or greater.\n\nBlender Path:\n%s%s") % (self.form.settings.general["blender_command"], version_message))
 		
 		# Enable the Render button again
 		self.btnRender.set_sensitive(True)
@@ -567,7 +627,7 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		length = end_frame - start_frame
 			
 		# add file to current project
-		f = self.project.project_folder.AddFile(first_image)
+		f = self.project.project_folder.AddFile(first_image, ignore_image_sequences=True)
 		
 		# Update the file properties (since it's added as an image)
 		# We need to make it look like a video
@@ -584,7 +644,7 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		
 				
 	def Render(self, frame=None):
-		""" Render an images sequence of the current template using Blender 2.5+ and the
+		""" Render an images sequence of the current template using Blender 2.56+ and the
 		Blender Python API. """
 
 		blend_file_path = os.path.join(self.project.BLENDER_DIR, "blend", self.selected_template)
@@ -662,17 +722,20 @@ class BlenderCommand(threading.Thread):
 			self.version = self.blender_version.findall(self.process.stdout.readline())
 
 			if self.version:
-				if float(self.version[0]) < 2.5:
-					# Wrong version of Blender.  Must be 2.5+:
+				if float(self.version[0]) < 2.56:
+					# Wrong version of Blender.  Must be 2.56+:
 					gobject.idle_add(self.frm3dGenerator.error_with_blender, float(self.version[0]))
 					return
 			
+			# debug info
+			print "Blender command: %s %s '%s' %s '%s'" % (command_render[0], command_render[1], command_render[2], command_render[3], command_render[4])
+			
 			# Run real command to render Blender project
 			self.process = subprocess.Popen(command_render, stdout=subprocess.PIPE)
 			
 		except:
 			# Error running command.  Most likely the blender executable path in the settings
-			# is not correct, or is not the correct version of Blender (i.e. 2.5+)
+			# is not correct, or is not the correct version of Blender (i.e. 2.56+)
 			gobject.idle_add(self.frm3dGenerator.error_with_blender)
 			return
 
