@@ -29,7 +29,7 @@ from language import Language_Init
 
 class frmClipProperties(SimpleGtkBuilderApp):
 
-	def __init__(self, path="ClipProperties.ui", root="frmClipProperties", domain="OpenShot", form=None, project=None, current_clip=None, current_clip_item=None, **kwargs):
+	def __init__(self, path="ClipProperties.ui", root="frmClipProperties", domain="OpenShot", form=None, project=None, current_clip=None, current_clip_item=None, initial_tab=0, **kwargs):
 		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
@@ -86,11 +86,12 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		
 		# init the default properties
 		self.txtFileName.set_text(fname)
-		self.txtLength.set_value(self.current_clip.length())
-		self.txtIn.set_value(round(self.current_clip.start_time, 11))
-		self.txtOut.set_value(round(self.current_clip.end_time, 11))
-		self.txtAudioFadeAmount.set_value(round(self.current_clip.audio_fade_amount, 11))
-		self.txtVideoFadeAmount.set_value(round(self.current_clip.video_fade_amount, 11))
+		self.txtLength.set_text(_("{0} seconds").format(str(self.current_clip.length())))
+		self.txtIn.set_value(round(self.current_clip.start_time, 2))
+		self.txtOut.set_value(round(self.current_clip.end_time, 2))
+		self.txtAudioFadeAmount.set_value(round(self.current_clip.audio_fade_amount, 2))
+		self.txtVideoFadeAmount.set_value(round(self.current_clip.video_fade_amount, 2))
+		self.txtRotate.set_value(round(self.current_clip.rotation, 2))
 		self.sliderVolume.set_value(self.current_clip.volume)
 		self.chkFill.set_active(self.current_clip.fill)
 		
@@ -113,6 +114,14 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		self.set_keyframe_dropdown()
 		self.set_speed_dropdown()
 		
+		# Hide the speed tab, if this is an image
+		if self.current_clip.file_object.file_type == "video":
+			# Speed only works for videos.  Image Sequences, audio, and images break with this setting.
+			# So, we only show this setting for videos.
+			self.vboxSpeed.set_property('visible', True)
+		else:
+			self.vboxSpeed.set_property('visible', False)
+		
 		# update effects tree
 		self.OSTreeEffects = TreeEffects.OpenShotTree(self.treeEffects, self.project)
 		self.update_effects_tree()
@@ -124,6 +133,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		self.form.MyVideo.play()
 		self.form.MyVideo.pause()
 		
+		# set the initial tab
+		self.notebook1.set_current_page(initial_tab)
+		
 		# mark project as modified
 		# so that the real project is refreshed... even if these 
 		# preview changes are not accepted
@@ -165,6 +177,8 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		clip_effect = self.get_clip_effect(unique_id)
 		
 		if real_effect:
+			# show the settings panel
+			self.vbox_effect_settings.set_property('visible', True) 
 			
 			# Clear Effect Edit Controls
 			self.clear_effect_controls()
@@ -173,7 +187,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			param_index = 1
 			for param in real_effect.params:
 				# get hbox
-				hbox = self.vboxcontainer.get_children()[param_index]
+				hbox = self.vbox_effect_settings.get_children()[param_index]
 				label = hbox.get_children()[0]
 				
 				# Get actual value for param
@@ -327,7 +341,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		
 		# Loop through all child hboxes
 		child_index = 0
-		for hbox in self.vboxcontainer.get_children():
+		for hbox in self.vbox_effect_settings.get_children():
 			
 			if child_index > 0: 
 				# get Label
@@ -347,6 +361,19 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# Populate effects tree again
 		self.OSTreeEffects.populate_tree(self.copy_of_clip.effects)
 		
+		# hide settings if no effects found
+		if not self.copy_of_clip.effects:
+			self.vbox_effect_settings.set_property('visible', False) 
+		else:
+			# select last effect
+			last_effect_index = len(self.copy_of_clip.effects) - 1
+			selection = self.treeEffects.get_selection()
+			selection.select_path((last_effect_index,))
+			
+			# call click event for the tree
+			self.on_treeEffects_button_release_event(self.treeEffects)
+		
+		
 
 	def get_selected_effect(self):
 		# Get Effect service name
@@ -417,9 +444,6 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# show frmExportVideo dialog
 		self.frmAddEffect = AddEffect.frmAddEffect(parent=self, form=self.form, project=self.project)
 		
-		# clear effect controls
-		self.clear_effect_controls()
-		
 
 	def on_btnRemoveEffect_clicked(self, widget, *args):
 		print "on_btnRemoveEffect_clicked"
@@ -429,12 +453,16 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		if selected_service:
 			# Remove effect
 			self.copy_of_clip.Remove_Effect(unique_id)
+			
+			# clear effect controls
+			self.clear_effect_controls()
 		
 			# update effect tree
 			self.update_effects_tree()
 			
-			# clear effect controls
-			self.clear_effect_controls()
+			# hide settings if no effects found
+			if not self.copy_of_clip.effects:
+				self.vbox_effect_settings.set_property("visible", False)
 		
 		
 	def on_btnEffectUp_clicked(self, widget, *args):
@@ -446,11 +474,12 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			# Move Effect
 			self.copy_of_clip.Move_Effect(unique_id, "up")
 			
-			# update effect tree
-			self.update_effects_tree()
-			
 			# clear effect controls
 			self.clear_effect_controls()
+			
+			# update effect tree
+			self.update_effects_tree()
+
 	
 	def on_btnEffectDown_clicked(self, widget, *args):
 		print "on_btnEffectDown_clicked"
@@ -461,11 +490,12 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			# Move Effect
 			self.copy_of_clip.Move_Effect(unique_id, "down")
 			
+			# clear effect controls
+			self.clear_effect_controls()
+			
 			# update effect tree
 			self.update_effects_tree()
 			
-			# clear effect controls
-			self.clear_effect_controls()
 
 	def on_btnResetVolume_clicked(self, widget, *args):
 		print "on_btnResetVolume_clicked"
@@ -497,8 +527,8 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# update property
 		self.keyframes[self.current_keyframe].y = self.txtY.get_value()
 		
-	def on_scaleAlpha_value_changed(self, widget, *args):
-		print "on_scaleAlpha_value_changed"
+	def on_txtAlpha_value_changed(self, widget, *args):
+		print "on_txtAlpha_value_changed"
 		
 		# update property
 		self.keyframes[self.current_keyframe].alpha = float(self.scaleAlpha.get_value()) / 100.0
@@ -555,27 +585,33 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		self.spinAdvancedSpeed.set_value(num / den)
 		
 	def on_txtIn_value_changed(self, widget, *args):
+		# get correct gettext method
+		_ = self._
+		
 		print "on_txtIn_value_changed"
 		local_in = float(self.txtIn.get_value())
 		local_out = float(self.txtOut.get_value())
 		
 		# is IN valid?
 		if local_in >= local_out:
-			local_in = local_out - 0.000000001
+			local_in = local_out - 0.01
 			self.txtIn.set_text(str(local_in))
 		
 		# update length
-		self.txtLength.set_text(str(round(local_out - local_in, 11)))
+		self.txtLength.set_text(_("{0} seconds").format(str(round(local_out - local_in, 2))))
 		
 	def on_txtOut_value_changed(self, widget, *args):
+		# get correct gettext method
+		_ = self._
+		
 		print "on_txtOut_value_changed"
 		local_in = float(self.txtIn.get_value())
 		local_out = float(self.txtOut.get_value())
-		local_max_length = self.current_clip.max_length
+		local_max_length = round(self.current_clip.max_length, 2)
 		
 		# is IN valid?
 		if local_out <= local_in:
-			local_out = local_in + 0.000000001
+			local_out = local_in + 0.01
 			self.txtOut.set_text(str(local_out))
 		
 		if local_out > local_max_length:
@@ -583,7 +619,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			self.txtOut.set_text(str(local_out))
 		
 		# update length
-		self.txtLength.set_text(str(round(local_out - local_in, 11)))
+		self.txtLength.set_text(_("{0} seconds").format(str(round(local_out - local_in, 2))))
 
 	def set_keyframe_dropdown(self):
 		# get the model and iterator of the project type dropdown box
@@ -749,13 +785,14 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		localcboEnableAudio = self.chkEnableAudio.get_active()
 		localtxtIn = self.txtIn.get_value()
 		localtxtOut = self.txtOut.get_value()
-		localtxtLength = self.txtLength.get_value()
+		localtxtLength = float(self.txtLength.get_text().split()[0])
 		localcboFill = self.chkFill.get_active()
 		localchkMaintainAspect = self.chkMaintainAspect.get_active()
 		localcboDirection = self.cboDirection.get_active_text().lower()
 		localsliderSpeed = self.spinAdvancedSpeed.get_value()
 		localtxtAudioFadeAmount = self.txtAudioFadeAmount.get_value()
 		localtxtVideoFadeAmount = self.txtVideoFadeAmount.get_value()
+		localtxtRotate = self.txtRotate.get_value()
 		localsliderVolume = self.sliderVolume.get_value()
 
 		# reset the IN, OUT textboxes to original speed
@@ -780,6 +817,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		clip_object.valign = localcboVAlign
 		clip_object.audio_fade_amount = localtxtAudioFadeAmount
 		clip_object.video_fade_amount = localtxtVideoFadeAmount
+		clip_object.rotation = localtxtRotate
 		clip_object.volume = localsliderVolume
 		
 		clip_object.video_fade_in = self.chkVideoFadeIn.get_active()
