@@ -31,6 +31,8 @@ import locale
 
 from classes import messagebox, profiles, project, video
 from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
+from windows import UploadVideo
+from uploads.manager import UploadManager
 
 # init the foreign language
 from language import Language_Init
@@ -79,14 +81,39 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		for file_name, p in self.profile_list:
 			# append profile to list
 			self.cmbProjectType.append_text(p.description())
-			
 					
 		export_options = [_("Video & Audio"), _("Image Sequence")]
 		# loop through export to options
 		for option in export_options:
 			# append profile to list
 			self.cboExportTo.append_text(option)
-			
+
+
+		export_types_model = self.cboExportType.get_model()
+		export_types_model.clear()
+		
+		export_types = [_("Export to Folder"), _("Upload to Web")]
+		# loop through export to options
+		for option in export_types:
+			# append profile to list
+			self.cboExportType.append_text(option)
+		self.set_dropdown_values(_("Export to Folder"), self.cboExportType)
+		
+		
+		upload_model = self.cboUploadServices.get_model()
+		upload_model.clear()
+		
+		self.upload_manager = UploadManager(project, self.form.settings)
+		self.upload_services = self.upload_manager.get_services()
+		upload_types = self.upload_services.keys()
+		upload_types.sort()
+		# loop through export to options
+		for option in upload_types:
+			# append profile to list
+			self.cboUploadServices.append_text(option)
+		self.set_dropdown_values(_("YouTube"), self.cboUploadServices)
+		
+
 		#populate the format/codec drop downs 
 		#formats
 		format_model = self.cboVIdeoFormat.get_model()
@@ -130,6 +157,26 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			
 		#indicate that exporting cancelled
 		self.cancelled = False
+		
+		# create the infobar displaying the missing codec message
+		self.use_infobar = True
+		self.last_error = None
+		try:
+			self.infobar = gtk.InfoBar()
+			self.content = self.infobar.get_content_area()
+			self.label = gtk.Label()
+			
+			self.image = gtk.Image()
+			self.image.set_from_stock(gtk.STOCK_DIALOG_WARNING, gtk.ICON_SIZE_DIALOG)
+			
+			self.content.add(self.image)
+			self.content.add(self.label)
+			self.vbox1.pack_start(self.infobar)
+			self.vbox1.reorder_child(self.infobar, 3)
+			self.infobar.set_message_type(gtk.MESSAGE_WARNING)
+		except:
+			# older version of pygtk can not create an InfoBar
+			self.use_infobar = False
 
 		
 	def set_project_type_dropdown(self):
@@ -188,6 +235,48 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		# set the item as active
 		self.cboExportTo.set_active_iter(iter)
 		
+		
+	def on_cboExportType_changed(self, widget, *args):
+		print "on_cboExportType_changed"
+		_ = self._
+		
+		export_type = self.cboExportType.get_active_text()
+		
+		if export_type == _("Export to Folder"):
+			self.fileExportFolder.set_property("visible", True)
+			self.cboUploadServices.set_property("visible", False)
+		else:
+			# show upload services
+			self.fileExportFolder.set_property("visible", False)
+			self.cboUploadServices.set_property("visible", True)
+
+			# auto select related profiles for this upload service
+			self.refresh_profiles_for_uploads()
+		
+	def on_cboUploadServices_changed(self, widget, *args):
+		print "on_cboUploadServices_changed"
+		
+		# auto select related profiles for this upload service
+		self.refresh_profiles_for_uploads()
+
+
+	def refresh_profiles_for_uploads(self):
+		
+		# get reference to gettext
+		_ = self._
+		export_type = self.cboExportType.get_active_text()
+
+		if export_type == _("Upload to Web"):
+			# get the upload service name
+			service_name = self.cboUploadServices.get_active_text()
+			service = self.upload_services[service_name]
+			
+			# get the preferred / related profiles for this upload service
+			project_type, project_target = service.get_export_presets()
+			
+			# init the dropdown boxes
+			self.set_dropdown_values(project_type, self.cboSimpleProjectType)
+			self.set_dropdown_values(project_target, self.cboSimpleTarget)
 
 	def on_cboSimpleProjectType_changed(self, widget, *args):
 		#set the target dropdown based on the selected project type 
@@ -217,9 +306,22 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		if selected_project == _("All Formats"):
 			# default to MP4 for this type
 			self.set_dropdown_values(_("OGG (theora/vorbis)"), self.cboSimpleTarget)
+			
+			# default the profile (based on the current project's profile)
+			#self.set_dropdown_values(_(self.project.project_type), self.cboSimpleVideoProfile)
+			
 		else:
 			# choose first taret
 			self.cboSimpleTarget.set_active(0)
+			
+
+		# default to 1st profile
+		#if not self.cboSimpleVideoProfile.get_active_text():
+		#	# still no profile, choose the 1st one
+		#	self.cboSimpleVideoProfile.set_active(0)
+		
+		# default quality (to lowest)	
+		#self.cboSimpleQuality.set_active(0)
 		
 		
 	def on_cboSimpleTarget_changed(self, widget, *args):
@@ -252,7 +354,6 @@ class frmExportVideo(SimpleGtkBuilderApp):
 						# show all profiles
 						for profile_node in self.profile_list:
 							profiles_list.append(_(profile_node[0]))
-						
 					
 					#get the video bit rate(s)
 					videobitrate = xmldoc.getElementsByTagName("videobitrate")
@@ -261,9 +362,7 @@ class frmExportVideo(SimpleGtkBuilderApp):
 						v_m = rate.attributes["med"].value
 						v_h = rate.attributes["high"].value
 						self.vbr = {_("Low"): v_l, _("Med"): v_m, _("High"): v_h}
-						
-						
-					
+
 					#get the audio bit rates
 					audiobitrate = xmldoc.getElementsByTagName("audiobitrate")
 					for audiorate in audiobitrate:
@@ -287,9 +386,6 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			# init the profiles combo
 			for item in sorted(profiles_list):
 				self.cboSimpleVideoProfile.append_text(item)
-				
-			# choose the default project type / profile (if it's listed)
-			#self.set_dropdown_values(self.project.project_type, self.cboSimpleVideoProfile)
 
 			#set the quality combo
 			#only populate with quality settings that exist
@@ -299,6 +395,19 @@ class frmExportVideo(SimpleGtkBuilderApp):
 				self.cboSimpleQuality.append_text(_("Med"))
 			if v_h or a_h:
 				self.cboSimpleQuality.append_text(_("High"))
+				
+				
+			# default the profile (based on the current project's profile)
+			self.set_dropdown_values(_(self.project.project_type), self.cboSimpleVideoProfile)
+
+			# default to 1st profile
+			if not self.cboSimpleVideoProfile.get_active_text():
+				# still no profile, choose the 1st one
+				self.cboSimpleVideoProfile.set_active(0)
+				
+			# default quality (to lowest)	
+			self.set_dropdown_values(_("Low"), self.cboSimpleQuality)
+			self.set_dropdown_values(_("Med"), self.cboSimpleQuality)
 			
 		
 	def on_cboSimpleVideoProfile_changed(self, widget, *args):
@@ -320,6 +429,7 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		
 			#set the value of the project type dropdown on the advanced tab
 			self.set_dropdown_values(profile,self.cmbProjectType)
+
 		
 	def on_cboSimpleQuality_changed(self, widget, *args):
 		
@@ -362,12 +472,22 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			#check for any invalid codecs and disable
 			#the export button if required.
 			if self.invalid_codecs:
-				missing_codecs = ""
-				for codec in self.invalid_codecs:
-					missing_codecs += codec + "\n"
+
+				if self.use_infobar:
+					self.label.set_markup(_("The following codec(s) are missing from your system:\n\n{missing_codecs}\n<a href='https://answers.launchpad.net/openshot/+faq/1040'>Learn More</a>".format(missing_codecs = "\n".join(self.invalid_codecs))))
+					self.infobar.show_all()
+				else:
+					# no infobar available (use messagebox)
+					if self.last_error != self.invalid_codecs:
+						messagebox.show(_("Error!"), _("The following codec(s) are missing from your system:\n\n{missing_codecs}\n".format(missing_codecs = "\n".join(self.invalid_codecs))))
 					
-				messagebox.show(_("Openshot Error"), _("The following formats/codecs are missing from your system:" + "\n\n" + "%s" % missing_codecs + "\nYou will not be able to use the selected export profile.  You will need to install the missing formats/codecs or choose a different export profile."))
+				self.last_error = self.invalid_codecs
 				self.btnExportVideo.set_sensitive(False)
+			else:
+				# hide the missing codec message again
+				if self.use_infobar:
+					self.last_error = None
+					self.infobar.hide()
 		
 			
 	def set_dropdown_values(self, value_to_set, combobox):
@@ -377,7 +497,7 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		
 		model = combobox.get_model()
 		iter = model.get_iter_first()
-		while True:
+		while iter:
 			# get the value of each item in the dropdown
 			value = model.get_value(iter, 0)
 			
@@ -429,17 +549,13 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		print "on_frmExportVideo_destroy"
 		self.cancelled = True
 		
-		# stop the export (if in-progress) by stopping the consumer
-		self.project.form.MyVideo.consumer_stop()
-			
 		# update the project type back to the original (before opening this dialog)
 		self.project.project_type = self.original_project_type
 		self.project.mlt_profile = None		# clear cached mlt_profile
 			
 		# create new SDL consumer (to resume playback / preview ability)
 		self.project.form.MyVideo.set_profile(self.project.project_type, load_xml=False)
-		self.project.form.MyVideo.new_sdl_consumer()
-
+		
 		# mark project as modified
 		self.project.set_project_modified(is_modified=self.project.is_modified, refresh_xml=True)
 		self.project.RefreshXML()
@@ -467,8 +583,8 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			
 		elif localcboExportTo == _("Video & Audio"):
 			self.expander3.set_expanded(False)	# image sequence
-			self.expander4.set_expanded(True)	# video settings
-			self.expander5.set_expanded(True)	# audio settings
+			self.expander4.set_expanded(False)	# video settings
+			self.expander5.set_expanded(False)	# audio settings
 			
 			# update filename
 			self.txtFileName.set_text(localtxtFileName) 
@@ -493,11 +609,20 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		
 		# get correct gettext method
 		_ = self._
+
+		# determine if we are UPLOADING or EXPORTING		
+		export_type = self.cboExportType.get_active_text()
+		if export_type == _("Upload to Web"):
+			# Override filename and location (for temp uploading)
+			localfileExportFolder = self.project.USER_DIR
+			localtxtFileName = "%s-upload" % str.strip(self.txtFileName.get_text())
+		else:
+			# Get filename and folder location
+			localfileExportFolder = str.strip(self.fileExportFolder.get_filename())
+			localtxtFileName = str.strip(self.txtFileName.get_text())
 		
 		# Get general settings
 		localcboExportTo = self.cboExportTo.get_active_text()
-		localfileExportFolder = str.strip(self.fileExportFolder.get_filename())
-		localtxtFileName = str.strip(self.txtFileName.get_text())
 		
 		# get project type
 		localcmbProjectType = self.cmbProjectType.get_active_text()
@@ -600,7 +725,7 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			self.export_path = "%s.%s" % (os.path.join(folder1, file1), self.render_options["f"])
 
 			#check for existing filename before export and confirm overwrite
-			if os.path.exists(self.export_path):
+			if os.path.exists(self.export_path) and export_type == _("Export to Folder"):
 				messagebox.show(_("Confirm Overwrite"), _("There is already a video file named %s.%s in the selected export folder. Would you like to overwrite it?") % (file1, self.render_options["f"]), gtk.BUTTONS_YES_NO, self.confirm_overwrite_yes)
 			else:
 				# no existing file, so export now
@@ -665,6 +790,25 @@ class frmExportVideo(SimpleGtkBuilderApp):
 				# Re-enable the controls on the screen
 				self.btnExportVideo.set_sensitive(True)
 				self.vbox1.set_sensitive(True)
+				
+				# Show Upload screen (if needed)
+				export_type = self.cboExportType.get_active_text()
+				if export_type == _("Upload to Web"):
+					localUploadService = self.cboUploadServices.get_active_text()
+					localfileExportFolder = self.project.USER_DIR
+					localtxtFileName = "%s-upload" % str.strip(self.txtFileName.get_text())
+					localtxtVideoFormat = self.cboVIdeoFormat.get_active_text()
+
+					# close this window
+					self.frmExportVideo.destroy()
+					
+					# show upload screen
+					frmUploadVideo = UploadVideo.frmUploadVideo(form=self.form, project=self.project, filename=os.path.join(localfileExportFolder, "%s.%s" % (localtxtFileName, localtxtVideoFormat)), service_name=localUploadService)
+					frmUploadVideo.frmUploadVideo.show()
+					
+				else:
+					# export is now finished, so close window
+					self.frmExportVideo.destroy()
 			
 			# flag export as completed
 			self.export_in_progress = False
