@@ -90,7 +90,7 @@ class frmFileproperties(SimpleGtkBuilderApp):
 		self.frmFileProperties.destroy()
 		
 def main():
-	frm_file_properties = frmFileProperties()
+	frm_file_properties = frmFileproperties()
 	frm_file_properties.run()
 
 if __name__ == "__main__":
