@@ -56,10 +56,6 @@ class frmProfilesManager(SimpleGtkBuilderApp):
 			
 		self.save_prompt = False
 		
-		image = gtk.Image()
-		image.set_from_stock(gtk.STOCK_ADD, gtk.ICON_SIZE_BUTTON)
-		self.btnImport.set_image(image)
-			
 		self.frmProfiles.show_all()
 		
 		#set the default profile
