@@ -47,6 +47,7 @@ class frmNewTitle(SimpleGtkBuilderApp):
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
+		self._ = _
 
 		self.project = project
 		self.form = form
@@ -273,13 +274,19 @@ class frmNewTitle(SimpleGtkBuilderApp):
 
 
 	def on_btnApply_clicked(self, widget):
+		# get translation method
+		_ = self._
 		
 		#import the file to the project.
 		self.project.project_folder.AddFile(self.filename)
 		self.project.thumbnailer.get_thumb_at_frame(self.filename)
 		self.frmTitles.destroy()
+		
+		# mark project as modified
+		self.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Edited title"))
+		
 		# refresh the main form
-		self.form.refresh()
+		self.form.refresh_files()
 
 	def find_in_list(self, l, value):
 		'''when passed a partial value, function will return the list index'''
